@@ -9,16 +9,44 @@ use std::{
 pub(crate) struct Waiter {
     stdin: JoinHandle<io::Result<()>>,
     stdout: JoinHandle<io::Result<Option<Vec<u8>>>>,
-    stderr: JoinHandle<io::Result<Vec<u8>>>,
+    stderr: JoinHandle<io::Result<Option<Vec<u8>>>>,
 }
 
 impl Waiter {
+    fn spawn_standard_stream_handler(
+        capture_stream: bool,
+        mut source: impl Read + Send + 'static,
+        mut relay_sink: impl Write + Send + 'static,
+    ) -> JoinHandle<io::Result<Option<Vec<u8>>>> {
+        thread::spawn(move || -> io::Result<Option<Vec<u8>>> {
+            let mut collected = if capture_stream {
+                Some(Vec::new())
+            } else {
+                None
+            };
+            let buffer = &mut [0; 256];
+            loop {
+                let length = source.read(buffer)?;
+                if (length) == 0 {
+                    break;
+                }
+                if let Some(collected) = &mut collected {
+                    collected.extend(&buffer[..length]);
+                }
+                if !capture_stream {
+                    relay_sink.write_all(&buffer[..length])?;
+                }
+            }
+            Ok(collected)
+        })
+    }
+
     pub(crate) fn spawn_standard_stream_relaying<Stdout, Stderr>(
         context: &Context<Stdout, Stderr>,
         config: &Config,
         mut child_stdin: ChildStdin,
-        mut child_stdout: ChildStdout,
-        mut child_stderr: ChildStderr,
+        child_stdout: ChildStdout,
+        child_stderr: ChildStderr,
     ) -> Self
     where
         Stdout: Write + Send + Clone + 'static,
@@ -29,46 +57,16 @@ impl Waiter {
             child_stdin.write_all(&config_stdin)?;
             Ok(())
         });
-        let mut context_clone = context.clone();
-        let capture_stdout = config.capture_stdout;
-        let stdout_join_handle = thread::spawn(move || -> io::Result<Option<Vec<u8>>> {
-            let mut collected_stdout = if capture_stdout {
-                Some(Vec::new())
-            } else {
-                None
-            };
-            let buffer = &mut [0; 256];
-            loop {
-                let length = child_stdout.read(buffer)?;
-                if (length) == 0 {
-                    break;
-                }
-                if let Some(collected_stdout) = &mut collected_stdout {
-                    collected_stdout.extend(&buffer[..length]);
-                }
-                if !capture_stdout {
-                    context_clone.stdout.write_all(&buffer[..length])?;
-                }
-            }
-            Ok(collected_stdout)
-        });
-        let mut context_clone = context.clone();
-        let capture_stderr = config.capture_stderr;
-        let stderr_join_handle = thread::spawn(move || -> io::Result<Vec<u8>> {
-            let mut collected_stderr = Vec::new();
-            let buffer = &mut [0; 256];
-            loop {
-                let length = child_stderr.read(buffer)?;
-                if (length) == 0 {
-                    break;
-                }
-                collected_stderr.extend(&buffer[..length]);
-                if !capture_stderr {
-                    context_clone.stderr.write_all(&buffer[..length])?;
-                }
-            }
-            Ok(collected_stderr)
-        });
+        let stdout_join_handle = Self::spawn_standard_stream_handler(
+            config.capture_stdout,
+            child_stdout,
+            context.stdout.clone(),
+        );
+        let stderr_join_handle = Self::spawn_standard_stream_handler(
+            config.capture_stderr,
+            child_stderr,
+            context.stderr.clone(),
+        );
         Waiter {
             stdin: stdin_join_handle,
             stdout: stdout_join_handle,
@@ -96,5 +94,5 @@ impl Waiter {
 #[derive(Debug)]
 pub(crate) struct CollectedOutput {
     pub(crate) stdout: Option<Vec<u8>>,
-    pub(crate) stderr: Vec<u8>,
+    pub(crate) stderr: Option<Vec<u8>>,
 }
