@@ -329,9 +329,6 @@ impl Input for String {
 ///
 /// let StdoutTrimmed(output) = run_output!(Split("echo foo"));
 /// assert_eq!(output, "foo");
-///
-/// let StdoutTrimmed(output) = run_output!(Split(format!("echo {}", 100)));
-/// assert_eq!(output, "100");
 /// ```
 ///
 /// Since this is such a common case, `cradle` also provides a syntactic shortcut
@@ -346,12 +343,12 @@ impl Input for String {
 ///
 /// [`split_whitespace`]: str::split_whitespace
 #[derive(Debug, PartialEq, Clone)]
-pub struct Split<T: AsRef<str>>(pub T);
+pub struct Split(pub &'static str);
 
-impl<T: AsRef<str>> Input for crate::input::Split<T> {
+impl Input for crate::input::Split {
     #[doc(hidden)]
     fn configure(self, config: &mut Config) {
-        for argument in self.0.as_ref().split_whitespace() {
+        for argument in self.0.split_whitespace() {
             argument.configure(config);
         }
     }
@@ -369,7 +366,7 @@ impl<T: AsRef<str>> Input for crate::input::Split<T> {
 /// Arguments to [`split`] must be of type [`char`].
 ///
 /// [`split`]: str::split
-impl<'a> Input for std::str::Split<'a, char> {
+impl Input for std::str::Split<'static, char> {
     #[doc(hidden)]
     fn configure(self, config: &mut Config) {
         for word in self {
@@ -388,7 +385,7 @@ impl<'a> Input for std::str::Split<'a, char> {
 /// ```
 ///
 /// [`split_whitespace`]: str::split_whitespace
-impl<'a> Input for std::str::SplitWhitespace<'a> {
+impl Input for std::str::SplitWhitespace<'static> {
     #[doc(hidden)]
     fn configure(self, config: &mut Config) {
         for word in self {
@@ -407,7 +404,7 @@ impl<'a> Input for std::str::SplitWhitespace<'a> {
 /// ```
 ///
 /// [`split_ascii_whitespace`]: str::split_ascii_whitespace
-impl<'a> Input for std::str::SplitAsciiWhitespace<'a> {
+impl Input for std::str::SplitAsciiWhitespace<'static> {
     #[doc(hidden)]
     fn configure(self, config: &mut Config) {
         for word in self {
@@ -442,6 +439,22 @@ tuple_impl!(0, A, 1, B, 2, C, 3, D,);
 tuple_impl!(0, A, 1, B, 2, C, 3, D, 4, E,);
 tuple_impl!(0, A, 1, B, 2, C, 3, D, 4, E, 5, F,);
 tuple_impl!(0, A, 1, B, 2, C, 3, D, 4, E, 5, F, 6, G,);
+tuple_impl!(0, A, 1, B, 2, C, 3, D, 4, E, 5, F, 6, G, 7, H,);
+tuple_impl!(0, A, 1, B, 2, C, 3, D, 4, E, 5, F, 6, G, 7, H, 8, I,);
+tuple_impl!(0, A, 1, B, 2, C, 3, D, 4, E, 5, F, 6, G, 7, H, 8, I, 9, J,);
+tuple_impl!(0, A, 1, B, 2, C, 3, D, 4, E, 5, F, 6, G, 7, H, 8, I, 9, J, 10, K,);
+tuple_impl!(0, A, 1, B, 2, C, 3, D, 4, E, 5, F, 6, G, 7, H, 8, I, 9, J, 10, K, 11, L,);
+tuple_impl!(0, A, 1, B, 2, C, 3, D, 4, E, 5, F, 6, G, 7, H, 8, I, 9, J, 10, K, 11, L, 12, M,);
+tuple_impl!(
+    0, A, 1, B, 2, C, 3, D, 4, E, 5, F, 6, G, 7, H, 8, I, 9, J, 10, K, 11, L, 12, M, 13, N,
+);
+tuple_impl!(
+    0, A, 1, B, 2, C, 3, D, 4, E, 5, F, 6, G, 7, H, 8, I, 9, J, 10, K, 11, L, 12, M, 13, N, 14, O,
+);
+tuple_impl!(
+    0, A, 1, B, 2, C, 3, D, 4, E, 5, F, 6, G, 7, H, 8, I, 9, J, 10, K, 11, L, 12, M, 13, N, 14, O,
+    15, P,
+);
 
 /// All elements of the given [`Vec`] are used as arguments to the child process.
 /// Same as passing in the elements separately.
@@ -510,7 +523,7 @@ where
 /// run!(LogCommand, %"echo foo");
 /// // writes '+ echo foo' to stderr
 /// ```
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Copy)]
 pub struct LogCommand;
 
 impl Input for LogCommand {
